==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggdialogrenderingprogress.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGDIALOGRENDERINGPROGRESS_H
#define IGGDIALOGRENDERINGPROGRESS_H


#include "iggdialog.h"


class vtkTimerLog;

class iggWidgetBase;
class iggWidgetTextArea;
class iggWidgetLogoFlipper;


class iggDialogRenderingProgress : public iggDialog
{

public:

	iggDialogRenderingProgress(iggMainWindow *parent);
	virtual ~iggDialogRenderingProgress();

	void Start();
	void KeepWorking();
	void Finish();

	void Cancel();
	inline bool IsCancelled() const { return mCancelled; }

protected:

	virtual bool CanBeClosed();

	bool mBlockParent, mCancelled, mShown;
	double mPreviousTime;
	vtkTimerLog *mTimer;
	iggWidgetLogoFlipper *mFlipper;
	iggWidgetTextArea *mElapsedTime;
	iggFrame *mButtonFrame, *mRemarkFrame;
};

#endif  //  IGGDIALOGRENDERINGPROGRESS_H

==> ifrit_3.2.5.orig.tar.gz: ifrit-3.2.5/shells/generic/iggdialogrenderingprogress.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGDIALOGRENDERINGPROGRESS_H
#define IGGDIALOGRENDERINGPROGRESS_H


#include "iggdialog.h"


class vtkTimerLog;

class iggWidgetBase;
class iggWidgetTextArea;
class iggWidgetLogoFlipper;


class iggDialogRenderingProgress : public iggDialog
{

public:

	iggDialogRenderingProgress(iggMainWindow *parent);
	virtual ~iggDialogRenderingProgress();

	void Start(bool interactive);
	void KeepWorking();
	void Finish();

	void Cancel();
	inline bool IsCancelled() const { return mCancelled; }

protected:

	virtual bool CanBeClosed();

	bool mBlockParent, mIsParentBlocked, mCancelled, mInteractive;
	double mPreviousTime;
	vtkTimerLog *mTimer;
	iggWidgetLogoFlipper *mFlipper;
	iggWidgetTextArea *mElapsedTime;
	iggFrame *mButtonFrame, *mRemarkFrame;
};

#endif  //  IGGDIALOGRENDERINGPROGRESS_H
